@@ -1,18 +1,17 @@
 package image
 
 import (
-	"fmt"
-
 	"github.com/spf13/cobra"
 
 	"k8s.io/cli-runtime/pkg/genericclioptions"
-	kcmdutil "k8s.io/kubernetes/pkg/kubectl/cmd/util"
-	ktemplates "k8s.io/kubernetes/pkg/kubectl/util/templates"
+	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
+	ktemplates "k8s.io/kubectl/pkg/util/templates"
 
 	"github.com/openshift/oc/pkg/cli/image/append"
 	"github.com/openshift/oc/pkg/cli/image/extract"
 	"github.com/openshift/oc/pkg/cli/image/info"
 	"github.com/openshift/oc/pkg/cli/image/mirror"
+	"github.com/openshift/oc/pkg/cli/image/serve"
 	cmdutil "github.com/openshift/oc/pkg/helpers/cmd"
 )
 
@@ -24,7 +23,7 @@ var (
 )
 
 // NewCmdImage exposes commands for modifying images.
-func NewCmdImage(fullName string, f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
+func NewCmdImage(f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
 	image := &cobra.Command{
 		Use:   "image COMMAND",
 		Short: "Useful commands for managing images",
@@ -32,16 +31,20 @@ func NewCmdImage(fullName string, f kcmdutil.Factory, streams genericclioptions.
 		Run:   kcmdutil.DefaultSubCommandRun(streams.ErrOut),
 	}
 
-	name := fmt.Sprintf("%s image", fullName)
-
 	groups := ktemplates.CommandGroups{
+		{
+			Message: "View or copy images:",
+			Commands: []*cobra.Command{
+				info.NewInfo(streams),
+				mirror.NewCmdMirrorImage(streams),
+			},
+		},
 		{
 			Message: "Advanced commands:",
 			Commands: []*cobra.Command{
-				append.NewCmdAppendImage(name, streams),
-				info.NewInfo(name, streams),
-				extract.New(name, streams),
-				mirror.NewCmdMirrorImage(name, streams),
+				serve.NewServe(streams),
+				append.NewCmdAppendImage(streams),
+				extract.NewExtract(streams),
 			},
 		},
 	}
